@@ -110,7 +110,7 @@ class ModelRegistry:
                     if "Contents" in response:
                         raise MlopsError(code=400, msg=f"Model binary & meta files already exist on {model_path}.")
 
-            for file_name in ["model.joblib", "model.json", "model.tar.gz"]:
+            for file_name in ["model.joblib", "model.json"]:
                 try:
                     client.upload_file(
                         Filename=f"{str(path)}/{file_name}", Bucket=bucket_name, Key=f"{model_path}/{file_name}"
